Changelog
=========

0.1.1 (2015-03-29)
------------------

* #14 - Add -s/--no-stat option to ignore overall stat changes when comparing new/old character data.

0.1.0 (2015-03-03)
-------------------

* #8 - Add --version command line option to print current version
* #10 - Ignore change to professions and total honorable kills when comparing new/old character data
* #5 - Added configuration support for global (all-character) options
* #5 - Added configuration support for number of threads to run

0.0.2 (2015-01-19)
------------------

* Rename project to be more clear

0.0.1 (2015-01-16)
------------------

* Initial development release (alpha), moved over from https://github.com/jantman/misc-scripts/blob/simc/nightly_simcraft.py
